@@ -15,7 +15,7 @@ import sys
 import argparse
 from functools import wraps
 
-from clitool.const import DEFAULT_ENCODING
+from clitool import DEFAULT_ENCODING
 from clitool.config import ConfigLoader
 
 
@@ -93,7 +93,7 @@ def parse_arguments(*args, **kwargs):
 
 
 def climain(func):
-    """ Annotation for main function to parse basic command line arguments..
+    """ Annotation for main function to parse basic command line arguments.
 
     ::
 
@@ -126,31 +126,20 @@ def climain(func):
     return wrapper
 
 
-def cliconfig(func):
-    """ Annotation if function requires configuration data.
+def cliconfig(fp, env=None):
+    """ Load configuration data.
 
-    First argument will be configuration data.
-
-    ::
-
-        @climain
-        @cliconfig
-        def main(config):
-            # your main function goes here
+    :param fp: opened file pointer of configuration
+    :type fp: FileType
+    :rtype: dict
     """
-
-    @wraps(func)
-    def wrapper(*args, **kwargs):
-        fp = kwargs.get('config')
-        if fp is None:
-            raise SystemExit('No configuration file is given.')
-        loader = ConfigLoader(fp)
-        cfg = loader.load()
-        assert cfg
-        del kwargs['config']
-        return func(cfg, *args, **kwargs)
-
-    return wrapper
+    if fp is None:
+        raise SystemExit('No configuration file is given.')
+    loader = ConfigLoader(fp)
+    cfg = loader.load(env)
+    if not cfg:
+        logging.warn('Configuration may be empty.')
+    return cfg
 
 
 if __name__ == '__main__':
